@@ -1,36 +1,42 @@
 #
 # @file   echo.py
 # @author Wei-Ning Huang (AZ) <aitjcize@gmail.com>
-# 
+#
 # Copyright (C) 2013 - 2014 Wei-Ning Huang (AZ) <aitjcize@gmail.com>
 # All Rights reserved.
-# 
+#
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
+# the Free Software Foundation; either version 3 of the License, or
 # (at your option) any later version.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software Foundation,
 # Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-# 
+#
+
+from __future__ import print_function
 
 import sys
-from tox import Tox, ToxAV
+from pytox import Tox, ToxAV
 
-from time import sleep, time
+from time import sleep
 from os.path import exists
-from random import randint
 
-SERVER = ["54.199.139.199", 33445, "7F9C31FE850E97CEFD4C4591DF93FC757C7C12549DDD55F8EEAECC34FE76C029"]
+SERVER = [
+    "54.199.139.199",
+    33445,
+    "7F9C31FE850E97CEFD4C4591DF93FC757C7C12549DDD55F8EEAECC34FE76C029"
+]
 
 DATA = 'echo.data'
 
+
 class AV(ToxAV):
     def __init__(self, core, max_calls):
         self.core = self.get_tox()
@@ -42,8 +48,8 @@ class AV(ToxAV):
         self.call_type = self.cs["call_type"]
 
         print("Incoming %s call from %d:%s ..." % (
-                "video" if self.call_type == self.TypeVideo else "audio", idx,
-                self.core.get_name(self.get_peer_id(idx, 0))))
+            "video" if self.call_type == self.TypeVideo else "audio", idx,
+            self.core.get_name(self.get_peer_id(idx, 0))))
 
         self.answer(idx, self.call_type)
         print("Answered, in call...")
@@ -52,9 +58,11 @@ class AV(ToxAV):
         try:
             self.change_settings(idx, {"max_video_width": 1920,
                                        "max_video_height": 1080})
-        except: pass
-        self.prepare_transmission(idx, self.jbufdc * 2, self.VADd,
-                True if self.call_type == self.TypeVideo else False)
+        except:
+            pass
+        self.prepare_transmission(
+            idx, self.jbufdc * 2, self.VADd,
+            True if self.call_type == self.TypeVideo else False)
 
     def on_end(self, idx):
         self.kill_transmission(idx)
@@ -77,6 +85,7 @@ class AV(ToxAV):
         sys.stdout.flush()
         self.send_video(idx, width, height, data)
 
+
 class EchoBot(Tox):
     def __init__(self):
         if exists(DATA):
