@@ -1,20 +1,63 @@
+#
+# @file   tests.py
+# @author Wei-Ning Huang (AZ) <aitjcize@gmail.com>
+#
+# Copyright (C) 2013 - 2014 Wei-Ning Huang (AZ) <aitjcize@gmail.com>
+# All Rights reserved.
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software Foundation,
+# Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+#
+
 import hashlib
 import os
 import re
+import sys
 import unittest
 
-from tox import Tox, OperationFailedError
+from pytox import Tox, OperationFailedError
 from time import sleep
 
 ADDR_SIZE = 76
 CLIENT_ID_SIZE = 64
 
+
+def unittest_skip(reason):
+    def _wrap1(func):
+        def _wrap2(self, *args, **kwargs):
+            pass
+        return _wrap2
+    return _wrap1
+
+
+def patch_unittest():
+    major, minor, micro, release, serial = sys.version_info
+    if major == 2 and minor <= 6:
+        unittest.skip = unittest_skip
+
+# Patch unittest for Python version <= 2.6
+patch_unittest()
+
+
 class AliceTox(Tox):
     pass
 
+
 class BobTox(Tox):
     pass
 
+
 class ToxTest(unittest.TestCase):
     def setUp(self):
         self.alice = AliceTox()
@@ -116,7 +159,7 @@ class ToxTest(unittest.TestCase):
 
         #: Wait until both are online
         def on_connection_status(self, friend_id, status):
-            assert status == True
+            assert status is True
             self.cs = True
 
         def on_user_status(self, friend_id, new_status):
@@ -215,6 +258,7 @@ class ToxTest(unittest.TestCase):
         self.bob_add_alice_as_friend()
 
         AID = self.aid
+
         def on_user_status(self, friend_id, new_status):
             assert friend_id == AID
             assert new_status == Tox.USERSTATUS_BUSY
@@ -238,9 +282,10 @@ class ToxTest(unittest.TestCase):
         self.bob_add_alice_as_friend()
 
         AID = self.aid
+
         def on_connection_status(self, friend_id, status):
             assert friend_id == AID
-            assert status == False
+            assert status is False
             self.cs = True
 
         BobTox.on_connection_status = on_connection_status
@@ -250,7 +295,7 @@ class ToxTest(unittest.TestCase):
         assert self.wait_callback(self.bob, 'cs')
         BobTox.on_connection_status = Tox.on_connection_status
 
-        assert self.bob.get_friend_connection_status(self.aid) == False
+        assert self.bob.get_friend_connection_status(self.aid) is False
 
     def test_tox(self):
         """
@@ -260,7 +305,7 @@ class ToxTest(unittest.TestCase):
         """
         assert self.alice.size() > 0
         data = self.alice.save()
-        assert data != None
+        assert data is not None
         addr = self.alice.get_address()
 
         self.alice.kill()
@@ -316,21 +361,22 @@ class ToxTest(unittest.TestCase):
 
         #: Test get_cliend_id
         assert self.alice.get_client_id(self.bid) == \
-                self.bob.get_address()[:CLIENT_ID_SIZE]
+            self.bob.get_address()[:CLIENT_ID_SIZE]
         assert self.bob.get_client_id(self.aid) == \
-                self.alice.get_address()[:CLIENT_ID_SIZE]
+            self.alice.get_address()[:CLIENT_ID_SIZE]
 
         #: Test friendlist
         assert self.alice.get_friendlist() == [self.bid]
         assert self.bob.get_friendlist() == [self.aid]
         assert self.alice.count_friendlist() == 1
         assert self.bob.count_friendlist() == 1
-        #assert self.alice.get_num_online_friends() == 1
-        #assert self.bob.get_num_online_friends() == 1
+        assert self.alice.get_num_online_friends() == 1
+        assert self.bob.get_num_online_friends() == 1
 
         #: Test friend name
         NEWNAME = 'Jenny'
         AID = self.aid
+
         def on_name_change(self, fid, newname):
             assert fid == AID
             assert newname == NEWNAME
@@ -358,6 +404,7 @@ class ToxTest(unittest.TestCase):
         #: Test message
         MSG = 'Hi, Bob!'
         BID = self.bid
+
         def on_friend_message(self, fid, message):
             assert fid == BID
             assert message == MSG
@@ -374,6 +421,7 @@ class ToxTest(unittest.TestCase):
         #: Test action
         ACTION = 'Kick'
         BID = self.bid
+
         def on_friend_action(self, fid, action):
             assert fid == BID
             assert action == ACTION
@@ -407,8 +455,8 @@ class ToxTest(unittest.TestCase):
         #: Test typing status
         def on_typing_change(self, fid, is_typing):
             assert fid == AID
-            assert is_typing == True
-            assert self.get_is_typing(fid) == True
+            assert is_typing is True
+            assert self.get_is_typing(fid) is True
             self.ut = True
 
         BobTox.on_typing_change = on_typing_change
@@ -418,8 +466,8 @@ class ToxTest(unittest.TestCase):
         BobTox.on_typing_change = Tox.on_typing_change
 
         #: Test last online
-        assert self.alice.get_last_online(self.bid) != None
-        assert self.bob.get_last_online(self.aid) != None
+        assert self.alice.get_last_online(self.bid) is not None
+        assert self.bob.get_last_online(self.aid) is not None
 
     def test_group(self):
         """
@@ -429,9 +477,12 @@ class ToxTest(unittest.TestCase):
         t:get_chatlist
         t:group_action_send
         t:group_get_names
+        t:group_get_title
+        t:group_get_type
         t:group_message_send
         t:group_number_peers
         t:group_peername
+        t:group_set_title
         t:invite_friend
         t:join_groupchat
         t:on_group_action
@@ -448,10 +499,12 @@ class ToxTest(unittest.TestCase):
         self.loop(50)
 
         BID = self.bid
-        def on_group_invite(self, fid, pk):
+
+        def on_group_invite(self, fid, type_, data):
             assert fid == BID
-            assert len(pk) == CLIENT_ID_SIZE
-            self.join_groupchat(fid, pk)
+            assert type_ == 0
+            gn = self.join_groupchat(fid, data)
+            assert type_ == self.group_get_type(gn)
             self.gi = True
 
         AliceTox.on_group_invite = on_group_invite
@@ -468,9 +521,7 @@ class ToxTest(unittest.TestCase):
 
         self.ensure_exec(self.bob.invite_friend, (self.aid, group_id))
 
-        assert self.wait_callback(self.alice, 'gi')
-        if not self.alice.gn:
-            assert self.wait_callback(self.alice, 'gn')
+        assert self.wait_callbacks(self.alice, ['gi', 'gn'])
 
         AliceTox.on_group_invite = Tox.on_group_invite
         AliceTox.on_group_namelist_change = Tox.on_group_namelist_change
@@ -501,10 +552,15 @@ class ToxTest(unittest.TestCase):
 
         assert sorted(self.bob.group_get_names(group_id)) == ['Alice', 'Bob']
 
+        #: Test title change
+        self.bob.group_set_title(group_id, 'My special title')
+        assert self.bob.group_get_title(group_id) == 'My special title'
+
         #: Test group message
         AID = self.aid
         BID = self.bid
         MSG = 'Group message test'
+
         def on_group_message(self, gid, fgid, message):
             if fgid == AID:
                 assert gid == group_id
@@ -523,6 +579,7 @@ class ToxTest(unittest.TestCase):
         AID = self.aid
         BID = self.bid
         MSG = 'Group action test'
+
         def on_group_action(self, gid, fgid, action):
             if fgid == AID:
                 assert gid == group_id
@@ -589,8 +646,8 @@ class ToxTest(unittest.TestCase):
             CONTEXT['FILE'] += data
             CONTEXT['RECEIVED'] += len(data)
             if CONTEXT['RECEIVED'] < FILE_SIZE:
-                assert self.file_data_remaining(fid, file_number, 1) == \
-                        FILE_SIZE - CONTEXT['RECEIVED']
+                assert self.file_data_remaining(
+                    fid, file_number, 1) == FILE_SIZE - CONTEXT['RECEIVED']
 
         AliceTox.on_file_send_request = on_file_send_request
         AliceTox.on_file_control = on_file_control
@@ -611,16 +668,20 @@ class ToxTest(unittest.TestCase):
                 try:
                     while True:
                         if CONTEXT['SENT'] == FILE_SIZE:
-                            self.bob.file_send_control(self.aid, 0, FN,
-                                    Tox.FILECONTROL_FINISHED)
+                            self.bob.file_send_control(
+                                self.aid, 0, FN,
+                                Tox.FILECONTROL_FINISHED
+                            )
                             CONTEXT['START'] = False
                             break
                         else:
                             ed = CONTEXT['SENT'] + BLK
                             if ed > FILE_SIZE:
                                 ed = FILE_SIZE
-                            self.bob.file_send_data(self.aid, FN,
-                                    FILE[CONTEXT['SENT']:ed])
+                            self.bob.file_send_data(
+                                self.aid, FN,
+                                FILE[CONTEXT['SENT']:ed]
+                            )
                             CONTEXT['SENT'] = ed
                 except:
                     pass
@@ -636,9 +697,9 @@ class ToxTest(unittest.TestCase):
 
 if __name__ == '__main__':
     methods = set([x for x in dir(Tox)
-                     if not x[0].isupper() and not x[0] == '_'])
+                  if not x[0].isupper() and not x[0] == '_'])
     docs = "".join([getattr(ToxTest, x).__doc__ for x in dir(ToxTest)
-            if getattr(ToxTest, x).__doc__ != None])
+                    if getattr(ToxTest, x).__doc__ is not None])
 
     tested = set(re.findall(r't:(.*?)\n', docs))
     not_tested = methods.difference(tested)
